@@ -130,7 +130,7 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
 
             # Update log data every 5 minutes with energy values
             print(energy, f'\n{self.battery.remaining_energy_percentage * 100}% battery remaining')
-            with open('logs/Crown_Detection_on_drone_no_flight_probe.json', 'a+') as logfile:
+            with open('logs/Crowd_Detection_on_drone_no_flight_probe.json', 'a+') as logfile:
                 json.dump(energy, logfile)
                 logfile.write('\n')
 
